package com.cisco.ccl.b2b.kc.controller;

import com.cisco.ccl.b2b.kc.model.Documents;
import com.cisco.ccl.b2b.kc.model.DocumentsBuilder;
import com.cisco.ccl.b2b.kc.service.DocumentService;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;

import static com.cisco.ccl.b2b.kc.util.ClasspathUtil.readFromClasspath;
import static com.cisco.ccl.b2b.kc.util.JsonMatcher.matches;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;
import static org.mockito.MockitoAnnotations.initMocks;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.content;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
import static org.springframework.test.web.servlet.setup.MockMvcBuilders.standaloneSetup;

public class DocumentControllerTest {

    private DocumentController documentController;

    @Mock
    private DocumentService documentService;

    @Before
    public void setUp() {
        initMocks(this);

        documentController = new DocumentController(documentService);
    }

    @Test
    public void shouldRetrieveAllDocuments() throws Exception {

        Documents documents = new DocumentsBuilder()
                .addDocument("123456", "ftp://localhost/123456")
                    .withMetadata("k1", "v1")
                .addDocument("123457", "ftp://localhost/123457")
                .build();

        when(documentService.loadAllDocuments()).thenReturn(documents);

        standaloneSetup(documentController).build()
                .perform(get("/documents"))
                .andExpect(status().isOk())
                .andExpect(content().string(matches(readFromClasspath("all-documents.json"))));

        verify(documentService).loadAllDocuments();

    }
}
