package com.cisco.ccl.b2b.kc.util;

import com.google.common.collect.ImmutableMap;
import org.junit.Test;

import java.util.Map;

import static name.mlnkrishnan.shouldJ.ShouldJ.it;

public class StringsTest {
    @Test
    public void shouldReplaceSingleToken() {

        String template = "i am {name}";
        String formattedString = Strings.format(template, ImmutableMap.of("name", "john"));

        it(formattedString).shouldBe("i am john");
    }

    @Test
    public void shouldReplaceMultipleTokens() {
        String template = "i am {name} and i live in {city}";
        String formattedString = Strings.format(template, ImmutableMap.of("name", "john", "city", "bangalore"));

        it(formattedString).shouldBe("i am john and i live in bangalore");
    }

    @Test
    public void shouldReplaceSameTokenMultipleTimes() {
        String template = "i am {name} and i live in {city} and am also called {name}";
        String formattedString = Strings.format(template, ImmutableMap.of("name", "john", "city", "bangalore"));

        it(formattedString).shouldBe("i am john and i live in bangalore and am also called john");

    }

    @Test
    public void shouldRetailTokenForNonMatchingToken() {
        String template = "i am {name} and i live in {city} and am also called {petName}";
        String formattedString = Strings.format(template, ImmutableMap.of("name", "john", "city", "bangalore"));

        it(formattedString).shouldBe("i am john and i live in bangalore and am also called {petName}");

    }

    @Test
    public void shouldRetainStringWithEmptyBraces() {
        String template = "i am {name} and i live in {}";
        String formattedString = Strings.format(template, ImmutableMap.of("name", "john", "city", "bangalore"));

        it(formattedString).shouldBe("i am john and i live in {}");

    }

    @Test
    public void shouldReplaceNonStringTokens() {
        String template = "i am {name} and i am {age} years old";
        Map valueMap = ImmutableMap.builder().put("name", "john").put("age", 50).build();
        String formattedString = Strings.format(template, valueMap);

        it(formattedString).shouldBe("i am john and i am 50 years old");

    }

}
