package fakerest;

import fakerest.mock.Developer;
import fakerest.request.HttpMethod;
import fakerest.request.Route;
import fakerest.request.RouteManager;
import fakerest.request.RouteRegister;
import fakerest.response.ContentType;
import fakerest.response.Response;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class HttpResponseForGETMethodTest {

	private RouteRegister subject;
	private Route route;

	@Before
	public void setUp() {
		route = new Route(HttpMethod.GET, "/test");
		subject = new RouteRegister(route);
	}

	@Test
	public void testPlainTextResponse() throws Exception {
		subject.thenReturnText("Hello World!");
		
		Response response = RouteManager.getInstance().get(route);

		assertEquals(ContentType.TEXT_PLAIN, response.getContentType());
		assertEquals("Hello World!", response.getContent());
	}


	
	@Test
	public void testJSONResponse() throws Exception {
		String simpleJSON = "{ \"name\": \"Bob\", \"age\": \"25\" }";
		subject.thenReturnJSON(simpleJSON);
		
		Response response = RouteManager.getInstance().get(route);

		assertEquals(ContentType.APPLICATION_JSON, response.getContentType());
		assertEquals(simpleJSON, response.getContent());
	}
	
	@Test
	public void testJSONObjectResponse() throws Exception {
		subject.thenReturnJSON(new Developer("Bob", 25));
		
		String expectedJSON = "{\"name\":\"Bob\",\"age\":25}";
		Response response = RouteManager.getInstance().get(route);

		assertEquals(ContentType.APPLICATION_JSON, response.getContentType());
		assertEquals(expectedJSON, response.getContent());
	}

	
}
