package fakerest.integration;

import fakerest.FakeRest;
import org.junit.Test;

import fakerest.mock.Developer;
import fakerest.request.HttpMethod;

public class RestServerGETTest extends IntegrationBaseTest {

	@Test
	public void requestPlainText() throws Exception {
		FakeRest.whenGet("/test").thenReturnText("Hello World!");
		FakeRest.startServer();

		requestGetWithResultString("Hello World!");
	}

	@Test
	public void requestJSON() throws Exception {
		String simpleJSON = "{ \"name\": \"Bob\", \"age\": \"25\" }";

		FakeRest.whenGet("/test").thenReturnJSON(simpleJSON);
		FakeRest.startServer();

		requestGetWithResultString(simpleJSON);
	}

	@Test
	public void requestJSONObject() throws Exception {
		FakeRest.whenGet("/test").thenReturnJSON(new Developer("Bob", 25));
		FakeRest.startServer();

		String expectedJSON = "{\"name\":\"Bob\",\"age\":25}";

		requestGetWithResultString(expectedJSON);
	}



	@Test
	public void requestPlainTextGetWithParameters() throws Exception {
		FakeRest.whenGet("/test").thenReturnText("Hello ${name}!");
		FakeRest.startServer();

		requestGetWithResultString(baseUrl + "/test?name=Bob", "Hello Bob!");
	}

	@Test
	public void requestPlainTextGetWithManyParameters() throws Exception {
		FakeRest.whenGet("/test").thenReturnText("Hello ${name}, you are the number #${number}!");
		FakeRest.startServer();

		requestGetWithResultString(baseUrl + "/test?name=Bob&number=1", "Hello Bob, you are the number #1!");
	}

	private void requestGetWithResultString(String url, String expectedBody) throws Exception {
		requestMethodWithResultString(url, expectedBody, HttpMethod.GET);
	}

	private void requestGetWithResultString(String expectedBody) throws Exception {
		requestMethodWithResultString(baseUrl + "/test", expectedBody, HttpMethod.GET);
	}

}
