package fakerest.integration;

import fakerest.FakeRest;
import fakerest.request.HttpMethod;
import org.eclipse.jetty.client.ContentExchange;
import org.eclipse.jetty.client.HttpExchange;
import org.eclipse.jetty.io.ByteArrayBuffer;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class RestServerPOSTTest extends IntegrationBaseTest {

	@Test
	public void postWithoutParametersWithPlainTextResponse() throws Exception {
		FakeRest.whenPost("/test").thenReturnText("Post succeed");
		FakeRest.startServer();

		requestPostWithResultString("Post succeed");
	}

	@Test
	public void postWithOneParameter() throws Exception {
		FakeRest.whenPost("/test").thenReturnText("Hello ${name}!");
		FakeRest.startServer();

		requestPostWithParameters(baseUrl + "/test", "name=Bob", "Hello Bob!");
	}

	@Test
	public void postWithManyParamters() throws Exception {
		FakeRest.whenPost("/test").thenReturnText("Hello ${name}! You are the number #${number} of #${total}.");
		FakeRest.startServer();

		requestPostWithParameters(baseUrl + "/test", "name=Bob&number=1&total=10", "Hello Bob! You are the number #1 of #10.");
	}

	private void requestPostWithResultString(String expectedBody) throws Exception {
		requestMethodWithResultString(baseUrl + "/test", expectedBody, HttpMethod.POST);
	}

	private void requestPostWithParameters(String url, String requestParamtersString, String resultString) throws Exception {
		ContentExchange exchange = new ContentExchange();
		exchange.setURL(url);
		exchange.setMethod(HttpMethod.POST.name());

		exchange.setRequestContent(new ByteArrayBuffer(requestParamtersString));
		exchange.setRequestContentType("application/x-www-form-urlencoded; charset=UTF-8");

		client.send(exchange);

		int exchangeState = exchange.waitForDone();

		assertEquals(HttpExchange.STATUS_COMPLETED, exchangeState);
		assertEquals(resultString + "\r\n", exchange.getResponseContent());
	}

}
