package fakerest.integration;

import fakerest.FakeRest;
import fakerest.request.HttpMethod;
import org.eclipse.jetty.client.ContentExchange;
import org.junit.Test;

import javax.servlet.http.HttpServletResponse;

import static org.junit.Assert.assertEquals;

public class RestServerReturningErrorsTest extends IntegrationBaseTest {
	
	@Test
	public void returningError404() throws Exception {
		FakeRest.whenGet("/test").thenReturnText("Hello World!");
		FakeRest.startServer();
		
		ContentExchange exchange = sendRequestAndWaitForDone(baseUrl + "/test1", HttpMethod.GET);
		
		assertEquals(HttpServletResponse.SC_NOT_FOUND, exchange.getResponseStatus());
	}
	
	@Test
	public void returningBadRequestForGETMethod() throws Exception {
		FakeRest.whenGet("/test").thenReturnErrorCodeWithMessage(HttpServletResponse.SC_BAD_REQUEST, "Message for error 500 GET");
		FakeRest.startServer();
		
		ContentExchange exchange = sendRequestAndWaitForDone(baseUrl + "/test", HttpMethod.GET);
		
		assertEquals(HttpServletResponse.SC_BAD_REQUEST, exchange.getResponseStatus());
		assertEquals("Message for error 500 GET\r\n", exchange.getResponseContent());
	}
	
	@Test
	public void returningBadRequestForPOSTMethod() throws Exception {
		FakeRest.whenPost("/test").thenReturnErrorCodeWithMessage(HttpServletResponse.SC_BAD_REQUEST, "Message for error 500 POST");
		FakeRest.startServer();
		
		ContentExchange exchange = sendRequestAndWaitForDone(baseUrl + "/test", HttpMethod.POST);
		
		assertEquals(HttpServletResponse.SC_BAD_REQUEST, exchange.getResponseStatus());
		assertEquals("Message for error 500 POST\r\n", exchange.getResponseContent());
	}
	
	@Test
	public void returningForbiddenForGETMethod() throws Exception {
		FakeRest.whenGet("/test").thenReturnErrorCodeWithMessage(HttpServletResponse.SC_FORBIDDEN, "Forbidden GET");
		FakeRest.startServer();
		
		ContentExchange exchange = sendRequestAndWaitForDone(baseUrl + "/test", HttpMethod.GET);
		
		assertEquals(HttpServletResponse.SC_FORBIDDEN, exchange.getResponseStatus());
		assertEquals("Forbidden GET\r\n", exchange.getResponseContent());
	}
	
	@Test
	public void returningForbiddenForPOSTMethod() throws Exception {
		FakeRest.whenPost("/test").thenReturnErrorCodeWithMessage(HttpServletResponse.SC_FORBIDDEN, "Forbidden POST");
		FakeRest.startServer();
		
		ContentExchange exchange = sendRequestAndWaitForDone(baseUrl + "/test", HttpMethod.POST);
		
		assertEquals(HttpServletResponse.SC_FORBIDDEN, exchange.getResponseStatus());
		assertEquals("Forbidden POST\r\n", exchange.getResponseContent());
	}

}
